<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Há vida fora do navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenciado para: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é um Software Livre, mas seu desenvolvimento toma um tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;doe&lt;/a&gt; para apoiar o desenvolvimento continuado de %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduza %1 para seu idioma nativo usando %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Produzido por %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Software open-source</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ícone desenhado por %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Lançado sob a &lt;a href=&apos;%1&apos;&gt;Licença Pública Geral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Insira os Detalhes da Licença</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-mail:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Código:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Por favor, licencie %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demonstração expirou.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>A versão completa permite que você assista vídeos sem interrupções.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sem licença, a aplicação irá expirar em %1 dias.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ao comprar a versão completa, você também apoiará o trabalho duro que eu dediquei ao criar %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar Demonstração</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Inserir Licença</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Adquirir Licença</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Por %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Você tem %n vídeo(s) novo(s)</numerusform><numerusform>Você tem %n vídeo(s) novo(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Todos Os Vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos Não Assistidos</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Última Atualização</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Último Adicionado</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Último Assistido</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Mais Assistidos</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marcar tudo como assistido</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Mostrar Atualização</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Você não tem assinaturas. Use o símbolo da estrela para assinar canais.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Todos Os Vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos Não Assistidos</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marcar como Assistido</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Cancelar assinatura</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Não há assinaturas atualizadas neste momento.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Neste exato momento</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n hora(s) atrás</numerusform><numerusform>%n hora(s) atrás</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n dia(s) atrás</numerusform><numerusform>%n dia(s) atrás</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n mes(es) atrás</numerusform><numerusform>%n mes(es) atrás</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizações</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n semana(s) atrás</numerusform><numerusform>%n semana(s) atrás</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restantes</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 baixados em %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Download terminou</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n Downloads</numerusform><numerusform>%n Download(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Alterar local...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Escolha o local de download</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Local de download alterado.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Downloads atuais ainda irão para o local anterior.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Baixando para: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>O arquivo executavel foi alterado, talvez por um virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 não vai funcionar. Tente instalar novamente.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproduzir/Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Parar reprodução após a faixa atual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Próxima faixa</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Faixa anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Encontrar vídeos e canais por palavra-chave</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Procurar vídeos por categoria</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Assinados</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Canais assinados</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sinta-se confortável</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Parar a reprodução e voltar à visualização da pesquisa</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Ante&amp;rior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ir para a faixa anterior</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Pu&amp;lar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pular para o próximo vídeo</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproduzir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar reprodução</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tela Cheia</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir para a tela cheia</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Modo &amp;Compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar a lista de reprodução e a barra de ferramentas</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Abrir a Página do &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir à página de vídeo do YouTube e pausar a reprodução</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiar o &amp;Link do YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar o link do vídeo atual do YouTube para a área de transferência</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiar a &amp;URL de Stream de Vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar a URL do stream de vídeo atual para a área de transferência</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Localizar &amp;Partes Do Vídeo</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Localizar partes de outro vídeo esperando na ordem certa</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remover os vídeos selecionados da lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover Para &amp;Cima</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover para cima os vídeos selecionados na lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover Para &amp;Baixo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover para baixo os vídeos selecionados na lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Limpar Buscas Recentes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Apagar o histórico de pesquisa. Não pode ser desfeito.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tchau</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Si&amp;te</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Faça uma &amp;Doação</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, apoie o desenvolvimento continuado de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informações sobre %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Volume mudo</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Iniciar &amp;Manualmente A Reprodução</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Iniciar manualmente a reprodução de vídeos</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Downloads</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Mostrar detalhes sobre os downloads de vídeo</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Download</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Baixar o vídeo atual</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>&amp;Salvar Captura De Tela</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>A&amp;ssinar um Canal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Compartilhar o vídeo atual usando %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-mail</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Sempre Acima</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Parar Após Este Vídeo</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Relatar um problema...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Refinar Pesquisa...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Mais...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Vídeos &amp;Relacionados</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Assistir vídeos relacionados com o atual</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Abrir no &amp;Navegador...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Modo Restrito</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Ocultar vídeos que podem conter conteúdo inapropriado</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Mostrar Barra De &amp;Menu</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Gosta do %1? Avalie-o!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Adquirir %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicação</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reprodução</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Lista de &amp;Reprodução</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Compartilhar</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visualizar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pressione %1 para aumentar o volume, %2 para diminuí-lo</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Escolher seu conteúdo local</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abrindo %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Você deseja sair de %1 com um download em curso?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Se você fechar %1 agora, este download será cancelado.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Fechar e cancelar download</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Aguardar o download terminar</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar a reprodução</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Carregando</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Deixar Em &amp;Tela Cheia</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume em %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume está mudo</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume não está mudo</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Máxima definição de vídeo definida para %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>A sua privacidade está segura agora</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Downloads finalizados</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versão %2 já está disponível.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar mais tarde</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Você ainda pode acessar a barra de menu pressionando a tecla ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Agora você pode colar o link do YouTube em outro programa</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Agora você pode colar a URL do stream de vídeo em outro programa</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>O link só será válido por um tempo limitado.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Baixando %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>parte</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episódio</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Envido de %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Cancelar a assinatura de %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Assinar %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Mudar para %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Não subscrito de %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Inscrito em %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Uma nova versão do %1 está disponível!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 está disponível. Você está usando %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Gostaria de fazer o download agora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Pular Esta Versão</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Me Lembre Mais Tarde</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar Atualização</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Escolher um vídeo</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Finalizado</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Parado</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Parar download</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mostrar em %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir pasta pai</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reiniciar download</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar Mais %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Sem vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Não há mais vídeos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevância</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Número De Visualizações</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Avaliação</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Dias</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Dias</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Breve</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Longo</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menos de 4 minutos</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Entre 4 e 20 minutos</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Mais de 20 minutos</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Alta Definição</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p ou superior</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>para começar a assistir vídeos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>uma palavra-chave</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Digite</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palavra-chave recente</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canais recentes</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Voltar</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Avançar</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Avançar para %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Voltar para %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Refinar Pesquisa</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Você quis dizer: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Alterar local...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Captura de tela salva em %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Local de capturas de tela alterado.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Mais Popular</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Baixando atualização...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Baixando %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Argélia</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Austrália</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bélgica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canadá</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colômbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>República Tcheca</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egito</translation>
    </message>
    <message>
        <source>France</source>
        <translation>França</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Alemanha</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Gana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grécia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungria</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Índia</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonésia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Itália</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japão</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordânia</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Quênia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malásia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>México</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marrocos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Holanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nova Zelândia</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigéria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipinas</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polônia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rússia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arábia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapura</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>África do Sul</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Coréia do Sul</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Espanha</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suécia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunísia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turquia</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emirados Árabes Unidos</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Reino Unido</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Iémen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Mundial</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Não foi possível obter stream de vídeo de %1</translation>
    </message>
</context>
</TS>